==> webkitgtk-2.27.3.tar.xz: webkitgtk-2.27.3/Source/WebCore/html/canvas/WebGLShader.h <==
/*
 * Copyright (C) 2009-2017 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 */

#pragma once

#if ENABLE(WEBGL)

#include "WebGLSharedObject.h"
#include <wtf/text/WTFString.h>

namespace WebCore {

class WebGLShader final : public WebGLSharedObject {
public:
    static Ref<WebGLShader> create(WebGLRenderingContextBase&, GC3Denum);
    virtual ~WebGLShader();

    GC3Denum getType() const { return m_type; }
    const String& getSource() const { return m_source; }

    void setSource(const String& source) { m_source = source; }

    bool isValid() const { return m_isValid; }
    void setValid(bool valid) { m_isValid = valid; }

private:
    WebGLShader(WebGLRenderingContextBase&, GC3Denum);

    void deleteObjectImpl(GraphicsContext3D*, Platform3DObject) final;

    GC3Denum m_type;
    String m_source;
    bool m_isValid;
};

} // namespace WebCore

#endif

==> webkitgtk-2.50.5.tar.xz: webkitgtk-2.50.5/Source/WebCore/html/canvas/WebGLShader.h <==
/*
 * Copyright (C) 2009-2017 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 */

#pragma once

#if ENABLE(WEBGL)

#include "WebGLObject.h"
#include <wtf/text/WTFString.h>

namespace WebCore {

class WebGLShader final : public WebGLObject {
public:
    static RefPtr<WebGLShader> create(WebGLRenderingContextBase&, GCGLenum);
    virtual ~WebGLShader();

    GCGLenum getType() const { return m_type; }
    const String& getSource() const { return m_source; }

    void setSource(const String& source) { m_source = source; }

    bool isUsable() const { return object(); }
    bool isInitialized() const { return true; }
private:
    WebGLShader(WebGLRenderingContextBase&, PlatformGLObject, GCGLenum);

    void deleteObjectImpl(const AbstractLocker&, GraphicsContextGL*, PlatformGLObject) final;

    GCGLenum m_type;
    String m_source;
};

} // namespace WebCore

#endif
